@@ -30,17 +30,20 @@ get_tilexy <- function(bbx,z){
 #' function to check input type and projection.  All input types convert to a
 #' SpatialPointsDataFrame for point elevation and bbx for raster.
 #' @importFrom sp wkt
+#' @importFrom sf st_crs
 #' @keywords internal
 loc_check <- function(locations, prj = NULL){
   
+  prj <- st_crs(prj)
+  
   #Convert sf locations to SP
   if("sf" %in% class(locations)){
     locations <- sf::as_Spatial(locations)
   }
   
   if(class(locations)=="data.frame"){ 
-    if(is.null(prj)){
-      stop("Please supply a valid WKT string.")
+    if(is.na(prj)){
+      stop("Please supply a valid crs.")
     }
     if(ncol(locations) > 2){
       df <- data.frame(locations[,3:ncol(locations)],
@@ -52,35 +55,35 @@ loc_check <- function(locations, prj = NULL){
       names(df) <- "elevation"
     }
     locations<-sp::SpatialPointsDataFrame(sp::coordinates(locations[,1:2]),
-                             proj4string = sp::CRS(prj),
+                             proj4string = sp::CRS(SRS_string = prj$wkt),
                              data = df)
   } else if(class(locations) == "SpatialPoints"){
-    if(is.null(sp::wkt(locations))& is.null(prj)){
-      stop("Please supply a valid WKT string.")
+    if(is.null(sp::wkt(locations))& is.na(prj)){
+      stop("Please supply a valid crs.")
     }
     
     if(is.null(sp::wkt(locations))){
-      sp::proj4string(locations)<-prj
+      locations <- sp::SpatialPoints(locations, proj4string = sp::CRS(SRS_string = prj$wkt))
     }
     locations<-sp::SpatialPointsDataFrame(locations,
                                           data = data.frame(elevation = 
                                                               vector("numeric",
                                                                      nrow(sp::coordinates(locations)))))
   } else if(class(locations) == "SpatialPointsDataFrame"){
-    if(is.null(sp::wkt(locations)) & is.null(prj)) {
-      stop("Please supply a valid WKT string.")
+    if(is.null(sp::wkt(locations)) & is.na(prj)) {
+      stop("Please supply a valid crs.")
     }
     if(is.null(sp::wkt(locations))){
-      sp::proj4string(locations)<-prj
+      locations <- sp::SpatialPoints(locations, proj4string = sp::CRS(SRS_string = prj$wkt))
     }
     locations@data <- data.frame(locations@data,
                                  elevation = vector("numeric",nrow(locations))) 
   } else if(attributes(class(locations)) %in% c("raster","sp")){
     if((is.null(sp::wkt(locations)) | 
        nchar(sp::wkt(locations)) == 0 |
-       is.na(sp::wkt(locations))) & is.null(prj)){
+       is.na(sp::wkt(locations))) & is.na(prj)){
      
-      stop("Please supply a valid WKT string.")
+      stop("Please supply a valid crs.")
     }
     if(is.null(sp::wkt(locations)) | 
        nchar(sp::wkt(locations)) == 0 |
@@ -90,9 +93,10 @@ loc_check <- function(locations, prj = NULL){
             stop("No distinct points, all values NA.")
           } else {
             locations <- raster::rasterToPoints(locations,spatial = TRUE)
-            sp::proj4string(locations)<-prj
+            sp::SpatialPoints(locations, proj4string = sp::CRS(SRS_string = prj$wkt))
           }
         } else {
+          browser()
           sp::proj4string(locations)<-prj
         }
     } else if(attributes(class(locations)) %in% c("raster")){
